@@ -38,11 +38,8 @@
 #include "enchant.h"
 #include "enchant-provider.h"
 
-#ifdef WITH_SYSTEM_MYSPELL
-#include <myspell.hxx>
-#else
-#include "enchant_myspell.hxx"
-#endif
+/* built against hunspell 1.1.3 on January 13, 2006 */
+#include "hunspell.hxx"
 
 ENCHANT_PLUGIN_DECLARE("Myspell")
 
@@ -66,7 +63,7 @@ public:
 private:
 	GIConv  m_translate_in; /* Selected translation from/to Unicode */
 	GIConv  m_translate_out;
-	MySpell *myspell;
+	Hunspell *myspell;
 };
 
 /***************************************************************************/
@@ -76,10 +73,21 @@ myspell_checker_get_prefix (void)
 {
 	char * data_dir = NULL;
 
+	/* Look for explicitly set registry values */
 	data_dir = enchant_get_registry_value ("Myspell", "Data_Dir");
 	if (data_dir)
 		return data_dir;
 
+	/* Dynamically locate library and search for modules relative to it. */
+	char * prefix = enchant_get_prefix_dir();
+	if(prefix)
+		{
+			data_dir = g_build_filename(prefix, "share", "enchant", "myspell", NULL);
+			g_free(prefix);
+			return data_dir;
+		}
+
+
 #ifdef ENCHANT_MYSPELL_DICT_DIR
 	return g_strdup (ENCHANT_MYSPELL_DICT_DIR);
 #else
@@ -228,7 +236,6 @@ MySpellChecker::requestDictionary(const char *szLang)
 {
 	const char *dictBase = NULL;
 	char *dic = NULL, *aff = NULL;
-	char *home_dir = enchant_get_user_home_dir();
 
 	dic = myspell_request_dictionary (szLang);
 	if (!dic) {
@@ -247,7 +254,7 @@ MySpellChecker::requestDictionary(const char *szLang)
 	aff = g_strdup(dic);
 	int len_dic = strlen(dic);
 	strcpy(aff+len_dic-3, "aff");
-	myspell = new MySpell(aff, dic);
+	myspell = new Hunspell(aff, dic);
 	g_free(dic);
 	g_free(aff);
 	char *enc = myspell->get_dic_encoding();
@@ -315,8 +322,6 @@ myspell_provider_list_dicts (EnchantProvider * me,
 			    size_t * out_n_dicts)
 {
 	char ** dictionary_list = NULL;
-	*out_n_dicts = 0;
-
 	std::vector<std::string> dicts;
        	
 	char * home_dir = enchant_get_user_home_dir ();
@@ -339,13 +344,11 @@ myspell_provider_list_dicts (EnchantProvider * me,
 	if (dicts.size () > 0) {
 		dictionary_list = g_new0 (char *, dicts.size() + 1);
 
-		for (int i = 0; i < dicts.size(); i++) {
+		for (int i = 0; i < dicts.size(); i++)
 			dictionary_list[i] = g_strdup (dicts[i].c_str());
-		}
-
-		*out_n_dicts = dicts.size ();
 	}
 
+	*out_n_dicts = dicts.size ();
 	return dictionary_list;
 }
 
